/****************************************************************************
** Meta object code from reading C++ file 'board.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/bomber-17.12.3/src/board.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'board.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BomberBoard_t {
    QByteArrayData data[11];
    char stringdata0[126];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BomberBoard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BomberBoard_t qt_meta_stringdata_BomberBoard = {
    {
QT_MOC_LITERAL(0, 0, 11), // "BomberBoard"
QT_MOC_LITERAL(1, 12, 12), // "onPlaneCrash"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 13), // "playBombSound"
QT_MOC_LITERAL(4, 40, 14), // "playCrashSound"
QT_MOC_LITERAL(5, 55, 9), // "onBombHit"
QT_MOC_LITERAL(6, 65, 12), // "levelCleared"
QT_MOC_LITERAL(7, 78, 15), // "settingsChanged"
QT_MOC_LITERAL(8, 94, 4), // "tick"
QT_MOC_LITERAL(9, 99, 13), // "planeExploded"
QT_MOC_LITERAL(10, 113, 12) // "bombExploded"

    },
    "BomberBoard\0onPlaneCrash\0\0playBombSound\0"
    "playCrashSound\0onBombHit\0levelCleared\0"
    "settingsChanged\0tick\0planeExploded\0"
    "bombExploded"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BomberBoard[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    0,   61,    2, 0x06 /* Public */,
       5,    0,   62,    2, 0x06 /* Public */,
       6,    0,   63,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   64,    2, 0x0a /* Public */,
       8,    0,   65,    2, 0x08 /* Private */,
       9,    0,   66,    2, 0x08 /* Private */,
      10,    0,   67,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void BomberBoard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        BomberBoard *_t = static_cast<BomberBoard *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onPlaneCrash(); break;
        case 1: _t->playBombSound(); break;
        case 2: _t->playCrashSound(); break;
        case 3: _t->onBombHit(); break;
        case 4: _t->levelCleared(); break;
        case 5: _t->settingsChanged(); break;
        case 6: _t->tick(); break;
        case 7: _t->planeExploded(); break;
        case 8: _t->bombExploded(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (BomberBoard::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberBoard::onPlaneCrash)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (BomberBoard::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberBoard::playBombSound)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (BomberBoard::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberBoard::playCrashSound)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (BomberBoard::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberBoard::onBombHit)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (BomberBoard::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberBoard::levelCleared)) {
                *result = 4;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject BomberBoard::staticMetaObject = {
    { &QGraphicsScene::staticMetaObject, qt_meta_stringdata_BomberBoard.data,
      qt_meta_data_BomberBoard,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *BomberBoard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BomberBoard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BomberBoard.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int BomberBoard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void BomberBoard::onPlaneCrash()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BomberBoard::playBombSound()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BomberBoard::playCrashSound()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BomberBoard::onBombHit()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BomberBoard::levelCleared()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
