/****************************************************************************
** Meta object code from reading C++ file 'bomber.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/bomber-17.12.3/src/bomber.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bomber.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Bomber_t {
    QByteArrayData data[15];
    char stringdata0[154];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Bomber_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Bomber_t qt_meta_stringdata_Bomber = {
    {
QT_MOC_LITERAL(0, 0, 6), // "Bomber"
QT_MOC_LITERAL(1, 7, 9), // "closeGame"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 7), // "newGame"
QT_MOC_LITERAL(4, 26, 9), // "pauseGame"
QT_MOC_LITERAL(5, 36, 13), // "showHighscore"
QT_MOC_LITERAL(6, 50, 12), // "displayLevel"
QT_MOC_LITERAL(7, 63, 5), // "level"
QT_MOC_LITERAL(8, 69, 12), // "displayScore"
QT_MOC_LITERAL(9, 82, 5), // "score"
QT_MOC_LITERAL(10, 88, 12), // "displayLives"
QT_MOC_LITERAL(11, 101, 5), // "lives"
QT_MOC_LITERAL(12, 107, 16), // "gameStateChanged"
QT_MOC_LITERAL(13, 124, 23), // "BomberGameWidget::State"
QT_MOC_LITERAL(14, 148, 5) // "state"

    },
    "Bomber\0closeGame\0\0newGame\0pauseGame\0"
    "showHighscore\0displayLevel\0level\0"
    "displayScore\0score\0displayLives\0lives\0"
    "gameStateChanged\0BomberGameWidget::State\0"
    "state"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Bomber[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x08 /* Private */,
       3,    0,   55,    2, 0x08 /* Private */,
       4,    0,   56,    2, 0x08 /* Private */,
       5,    0,   57,    2, 0x08 /* Private */,
       6,    1,   58,    2, 0x08 /* Private */,
       8,    1,   61,    2, 0x08 /* Private */,
      10,    1,   64,    2, 0x08 /* Private */,
      12,    1,   67,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,    7,
    QMetaType::Void, QMetaType::UInt,    9,
    QMetaType::Void, QMetaType::UInt,   11,
    QMetaType::Void, 0x80000000 | 13,   14,

       0        // eod
};

void Bomber::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Bomber *_t = static_cast<Bomber *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->closeGame(); break;
        case 1: _t->newGame(); break;
        case 2: _t->pauseGame(); break;
        case 3: _t->showHighscore(); break;
        case 4: _t->displayLevel((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 5: _t->displayScore((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 6: _t->displayLives((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 7: _t->gameStateChanged((*reinterpret_cast< BomberGameWidget::State(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Bomber::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_Bomber.data,
      qt_meta_data_Bomber,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Bomber::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Bomber::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Bomber.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Bomber::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
