// This file is generated by kconfig_compiler_kf5 from bomber.kcfg.
// All changes you do to this file will be lost.
#ifndef BOMBERSETTINGS_H
#define BOMBERSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class BomberSettings : public KConfigSkeleton
{
  public:

    static BomberSettings *self();
    ~BomberSettings();

    /**
      Set Whether game sounds are played.
    */
    static
    void setPlaySounds( bool v )
    {
      if (!self()->isImmutable( QStringLiteral( "PlaySounds" ) ))
        self()->mPlaySounds = v;
    }

    /**
      Get Whether game sounds are played.
    */
    static
    bool playSounds()
    {
      return self()->mPlaySounds;
    }

  protected:
    BomberSettings();
    friend class BomberSettingsHelper;


    // Sound
    bool mPlaySounds;

  private:
};

#endif

