/****************************************************************************
** Meta object code from reading C++ file 'bomberwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/bomber-17.12.3/src/bomberwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bomberwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BomberGameWidget_t {
    QByteArrayData data[28];
    char stringdata0[294];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BomberGameWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BomberGameWidget_t qt_meta_stringdata_BomberGameWidget = {
    {
QT_MOC_LITERAL(0, 0, 16), // "BomberGameWidget"
QT_MOC_LITERAL(1, 17, 8), // "gameOver"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 12), // "levelChanged"
QT_MOC_LITERAL(4, 40, 5), // "level"
QT_MOC_LITERAL(5, 46, 12), // "scoreChanged"
QT_MOC_LITERAL(6, 59, 5), // "score"
QT_MOC_LITERAL(7, 65, 12), // "livesChanged"
QT_MOC_LITERAL(8, 78, 5), // "lives"
QT_MOC_LITERAL(9, 84, 11), // "timeChanged"
QT_MOC_LITERAL(10, 96, 4), // "time"
QT_MOC_LITERAL(11, 101, 12), // "stateChanged"
QT_MOC_LITERAL(12, 114, 23), // "BomberGameWidget::State"
QT_MOC_LITERAL(13, 138, 5), // "state"
QT_MOC_LITERAL(14, 144, 9), // "closeGame"
QT_MOC_LITERAL(15, 154, 7), // "newGame"
QT_MOC_LITERAL(16, 162, 9), // "setPaused"
QT_MOC_LITERAL(17, 172, 6), // "paused"
QT_MOC_LITERAL(18, 179, 15), // "settingsChanged"
QT_MOC_LITERAL(19, 195, 16), // "setSoundsEnabled"
QT_MOC_LITERAL(20, 212, 6), // "enable"
QT_MOC_LITERAL(21, 219, 12), // "setSuspended"
QT_MOC_LITERAL(22, 232, 5), // "value"
QT_MOC_LITERAL(23, 238, 10), // "onDropBomb"
QT_MOC_LITERAL(24, 249, 4), // "tick"
QT_MOC_LITERAL(25, 254, 9), // "onBombHit"
QT_MOC_LITERAL(26, 264, 14), // "onLevelCleared"
QT_MOC_LITERAL(27, 279, 14) // "onPlaneCrashed"

    },
    "BomberGameWidget\0gameOver\0\0levelChanged\0"
    "level\0scoreChanged\0score\0livesChanged\0"
    "lives\0timeChanged\0time\0stateChanged\0"
    "BomberGameWidget::State\0state\0closeGame\0"
    "newGame\0setPaused\0paused\0settingsChanged\0"
    "setSoundsEnabled\0enable\0setSuspended\0"
    "value\0onDropBomb\0tick\0onBombHit\0"
    "onLevelCleared\0onPlaneCrashed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BomberGameWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x06 /* Public */,
       3,    1,  100,    2, 0x06 /* Public */,
       5,    1,  103,    2, 0x06 /* Public */,
       7,    1,  106,    2, 0x06 /* Public */,
       9,    1,  109,    2, 0x06 /* Public */,
      11,    1,  112,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,  115,    2, 0x0a /* Public */,
      15,    0,  116,    2, 0x0a /* Public */,
      16,    1,  117,    2, 0x0a /* Public */,
      18,    0,  120,    2, 0x0a /* Public */,
      19,    1,  121,    2, 0x0a /* Public */,
      21,    1,  124,    2, 0x0a /* Public */,
      23,    0,  127,    2, 0x0a /* Public */,
      24,    0,  128,    2, 0x08 /* Private */,
      25,    0,  129,    2, 0x08 /* Private */,
      26,    0,  130,    2, 0x08 /* Private */,
      27,    0,  131,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,    4,
    QMetaType::Void, QMetaType::UInt,    6,
    QMetaType::Void, QMetaType::UInt,    8,
    QMetaType::Void, QMetaType::UInt,   10,
    QMetaType::Void, 0x80000000 | 12,   13,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, QMetaType::Bool,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void BomberGameWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        BomberGameWidget *_t = static_cast<BomberGameWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->gameOver(); break;
        case 1: _t->levelChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 2: _t->scoreChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 3: _t->livesChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 4: _t->timeChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 5: _t->stateChanged((*reinterpret_cast< BomberGameWidget::State(*)>(_a[1]))); break;
        case 6: _t->closeGame(); break;
        case 7: _t->newGame(); break;
        case 8: _t->setPaused((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->settingsChanged(); break;
        case 10: _t->setSoundsEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->setSuspended((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->onDropBomb(); break;
        case 13: _t->tick(); break;
        case 14: _t->onBombHit(); break;
        case 15: _t->onLevelCleared(); break;
        case 16: _t->onPlaneCrashed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (BomberGameWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberGameWidget::gameOver)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (BomberGameWidget::*_t)(unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberGameWidget::levelChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (BomberGameWidget::*_t)(unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberGameWidget::scoreChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (BomberGameWidget::*_t)(unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberGameWidget::livesChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (BomberGameWidget::*_t)(unsigned int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberGameWidget::timeChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (BomberGameWidget::*_t)(BomberGameWidget::State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BomberGameWidget::stateChanged)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject BomberGameWidget::staticMetaObject = {
    { &QGraphicsView::staticMetaObject, qt_meta_stringdata_BomberGameWidget.data,
      qt_meta_data_BomberGameWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *BomberGameWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BomberGameWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BomberGameWidget.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int BomberGameWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void BomberGameWidget::gameOver()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BomberGameWidget::levelChanged(unsigned int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void BomberGameWidget::scoreChanged(unsigned int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void BomberGameWidget::livesChanged(unsigned int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void BomberGameWidget::timeChanged(unsigned int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void BomberGameWidget::stateChanged(BomberGameWidget::State _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
